@@ -9,7 +9,6 @@ from onapsdk.configuration import settings
 from onapsdk.onap_service import OnapService
 from onapsdk.utils.headers_creator import headers_aai_creator
 from onapsdk.utils.jinja import jinja_env
-from onapsdk.utils.gui import GuiItem, GuiList
 
 from onapsdk.exceptions import RelationshipNotFound, ResourceNotFound
 
@@ -57,38 +56,16 @@ class AaiElement(OnapService):
     api_version = "/aai/" + settings.AAI_API_VERSION
     headers = headers_aai_creator(OnapService.headers)
 
-    @classmethod
-    def get_guis(cls) -> GuiItem:
-        """Retrieve the status of the AAI GUIs.
-
-        Only one GUI is referenced for AAI
-        the AAI sparky GUI
-
-        Return the list of GUIs
-        """
-        gui_url = settings.AAI_GUI_SERVICE
-        aai_gui_response = cls.send_message(
-            "GET", "Get AAI GUI Status", gui_url)
-        guilist = GuiList([])
-        guilist.add(GuiItem(
-            gui_url,
-            aai_gui_response.status_code))
-        return guilist
-
-
-class AaiResource(AaiElement):
-    """A&AI resource class."""
-
     @classmethod
     def filter_none_key_values(cls, dict_to_filter: Dict[str, Optional[str]]) -> Dict[str, str]:
         """Filter out None key values from dictionary.
 
-        Iterate through given dictionary and filter None values.
+        Iterate throught given dictionary and filter None values.
 
         Args:
             dict_to_filter (Dict): Dictionary to filter out None
 
-        Returns:dataclasse init a field
+        Returns:
             Dict[str, str]: Filtered dictionary
 
         """
@@ -101,7 +78,7 @@ class AaiResource(AaiElement):
         """Resource's url.
 
         Returns:
-            str: Resource's urldataclasse init a field
+            str: Resource's url
 
         """
         raise NotImplementedError
@@ -136,33 +113,6 @@ class AaiResource(AaiElement):
                    f'Server: {self.server}. Url: {self.url}')
             raise RelationshipNotFound(msg) from exc
 
-    @classmethod
-    def get_all_url(cls, *args, **kwargs) -> str:
-        """Return an url for all objects of given class.
-
-        Returns:
-            str: URL to get all objects of given class
-
-        """
-        raise NotImplementedError
-
-    @classmethod
-    def count(cls, *args, **kwargs) -> int:
-        """Get the count number of all objects of given class.
-
-        Get the response, iterate through response (each class has different response)
-            -- the first key value is the count.
-
-        Returns:
-            int: Count of the objects
-
-        """
-        return next(iter(cls.send_message_json(
-            "GET",
-            f"Get count of {cls.__name__} class instances",
-            f"{cls.get_all_url(*args, **kwargs)}?format=count"
-        )["results"][0].values()))
-
     def add_relationship(self, relationship: Relationship) -> None:
         """Add relationship to aai resource.
 
