@@ -1,9 +1,13 @@
 """A&AI business package."""
 from .customer import Customer, ServiceSubscription
 from .instance import Instance
+from .line_of_business import LineOfBusiness
 from .network import NetworkInstance
 from .owning_entity import OwningEntity
+from .platform import Platform
 from .pnf import PnfInstance
+from .project import Project
 from .service import ServiceInstance
+from .sp_partner import SpPartner
 from .vf_module import VfModuleInstance
 from .vnf import VnfInstance
