@@ -378,11 +378,6 @@ class SdcResource(SdcOnboardable, ABC):  # pylint: disable=too-many-instance-att
             self.submit()
             time.sleep(self._time_wait)
             self.onboard()
-        elif self.status == const.CHECKED_IN:
-            # Checked in status check added
-            self.certify()
-            time.sleep(self._time_wait)
-            self.onboard()
         elif self.status == const.CERTIFIED:
             self.load()
 
@@ -733,27 +728,6 @@ class SdcResource(SdcOnboardable, ABC):  # pylint: disable=too-many-instance-att
         msg = f"SDC resource {sdc_resource.name} is not a component"
         raise ResourceNotFound(msg)
 
-    def get_component_by_name(self, component_name: str) -> Component:
-        """Get resource's component by it's name.
-
-        Get component by name.
-
-        Args:
-            component_name (str): Component's name
-
-        Raises:
-            ResourceNotFound: Component with given name does not exist
-
-        Returns:
-            Component: Component object
-
-        """
-        for component in self.components:
-            if component.sdc_resource.name == component_name:
-                return component
-        msg = f"SDC resource {component_name} is not a component"
-        raise ResourceNotFound(msg)
-
     def declare_input_for_own_property(self, property_obj: Property) -> None:
         """Declare input for resource's property.
 
@@ -908,13 +882,6 @@ class SdcResource(SdcOnboardable, ABC):  # pylint: disable=too-many-instance-att
         if result:
             self.load()
 
-    def certify(self) -> None:
-        """Certify SDC resource."""
-        self._logger.debug("Certify %s SDC resource", self.name)
-        result = self._action_to_sdc(const.CERTIFY, "lifecycleState")
-        if result:
-            self.load()
-
     def add_resource(self, resource: 'SdcResource') -> None:
         """
         Add a Resource.
